==> dune-uggrid-2.9.1-1-x86_64.pkg.tar.zst: usr/lib/cmake/dune-uggrid/dune-uggrid-config.cmake <==
if(NOT dune-uggrid_FOUND)
# Whether this module is installed or not
set(dune-uggrid_INSTALLED ON)

# Settings specific to the module
set(UG_PARALLEL True)
# Package initialization

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was dune-uggrid-config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/dune-uggrid" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

#report other information
set_and_check(dune-uggrid_PREFIX "${PACKAGE_PREFIX_DIR}")
set_and_check(dune-uggrid_INCLUDE_DIRS "${PACKAGE_PREFIX_DIR}/include")
set(dune-uggrid_CXX_FLAGS "-std=c++17 -Wall -fdiagnostics-color=always -mavx")
set(dune-uggrid_CXX_FLAGS_DEBUG "-g")
set(dune-uggrid_CXX_FLAGS_MINSIZEREL "-Os -DNDEBUG")
set(dune-uggrid_CXX_FLAGS_RELEASE "-O3 -DNDEBUG")
set(dune-uggrid_CXX_FLAGS_RELWITHDEBINFO "-O2 -g -DNDEBUG")
set(dune-uggrid_DEPENDS "dune-common (>= 2.9)")
set(dune-uggrid_SUGGESTS "")
set(dune-uggrid_MODULE_PATH "${PACKAGE_PREFIX_DIR}/share/dune/cmake/modules")
set(dune-uggrid_LIBRARIES "duneuggrid")
set(dune-uggrid_HASPYTHON 0)
set(dune-uggrid_PYTHONREQUIRES "")

# Lines that are set by the CMake build system via the variable DUNE_CUSTOM_PKG_CONFIG_SECTION


#import the target
if(dune-uggrid_LIBRARIES)
  get_filename_component(_dir "${CMAKE_CURRENT_LIST_FILE}" PATH)
  include("${_dir}/dune-uggrid-targets.cmake")
endif()

endif()

==> dune-uggrid-2.10.0-1-x86_64.pkg.tar.zst: usr/lib/cmake/dune-uggrid/dune-uggrid-config.cmake <==
if(NOT dune-uggrid_FOUND)
# Whether this module is installed or not
set(dune-uggrid_INSTALLED ON)

# Settings specific to the module
set(UG_PARALLEL True)
# Package initialization

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was dune-uggrid-config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/dune-uggrid" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

#report other information
set_and_check(dune-uggrid_PREFIX "${PACKAGE_PREFIX_DIR}")
set_and_check(dune-uggrid_INCLUDE_DIRS "${PACKAGE_PREFIX_DIR}/include")
set(dune-uggrid_CMAKE_CONFIG_VERSION "2.10")
set(dune-uggrid_CXX_FLAGS "-Wall -fdiagnostics-color=always -mavx")
set(dune-uggrid_CXX_FLAGS_DEBUG "-g")
set(dune-uggrid_CXX_FLAGS_MINSIZEREL "-Os -DNDEBUG")
set(dune-uggrid_CXX_FLAGS_RELEASE "-O3 -DNDEBUG")
set(dune-uggrid_CXX_FLAGS_RELWITHDEBINFO "-O2 -g -DNDEBUG")
set(dune-uggrid_DEPENDS "dune-common (>= 2.10)")
set(dune-uggrid_SUGGESTS "")
set(dune-uggrid_MODULE_PATH "${PACKAGE_PREFIX_DIR}/share/dune/cmake/modules")
set(dune-uggrid_PYTHON_WHEELHOUSE "${PACKAGE_PREFIX_DIR}/share/dune/wheelhouse")
set(dune-uggrid_LIBRARIES "Dune::UGGrid")
set(dune-uggrid_HASPYTHON 0)
set(dune-uggrid_PYTHONREQUIRES "")

# Resolve dune dependencies
include(CMakeFindDependencyMacro)
macro(find_and_check_dune_dependency module version)
  find_dependency(${module})
  list(PREPEND CMAKE_MODULE_PATH "${dune-common_MODULE_PATH}")
  include(DuneModuleDependencies)
  list(POP_FRONT CMAKE_MODULE_PATH)
  if(dune-common_VERSION VERSION_GREATER_EQUAL "2.10")
    dune_check_module_version(${module} QUIET REQUIRED VERSION "${version}")
  endif()
endmacro()

find_and_check_dune_dependency(dune-common ">= 2.10")

# Set up DUNE_LIBS, DUNE_FOUND_DEPENDENCIES, DUNE_*_FOUND, and HAVE_* variables
if(dune-uggrid_LIBRARIES)
  message(STATUS "Setting dune-uggrid_LIBRARIES=${dune-uggrid_LIBRARIES}")
  list(PREPEND DUNE_LIBS ${dune-uggrid_LIBRARIES})
endif()
list(APPEND DUNE_FOUND_DEPENDENCIES dune-uggrid)
set(DUNE_dune-uggrid_FOUND TRUE)
set(HAVE_DUNE_UGGRID TRUE)

# Lines that are set by the CMake build system via the variable DUNE_CUSTOM_PKG_CONFIG_SECTION


# If this file is found in a super build that includes dune-uggrid, the 
# `dune-uggrid-targets.cmake`-file has not yet been generated. This variable
# determines whether the configuration of dune-uggrid has been completed.
get_property(dune-uggrid_IN_CONFIG_MODE GLOBAL PROPERTY dune-uggrid_LIBRARIES DEFINED)

#import the target
if(dune-uggrid_LIBRARIES AND NOT dune-uggrid_IN_CONFIG_MODE)
  get_filename_component(_dir "${CMAKE_CURRENT_LIST_FILE}" PATH)
  include("${_dir}/dune-uggrid-targets.cmake")
endif()

endif()
